==> job-scheduler_0.22.7.tar.xz: 64/translations/job-scheduler_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>User</source>
        <translation>ユーザー</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="118"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="36"/>
        <source>Max Item</source>
        <translation>アイテムの最大</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="38"/>
        <source>Max Date</source>
        <translation>最大の日付</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="40"/>
        <source>Select</source>
        <translation>選択</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="44"/>
        <source>&amp;Update</source>
        <translation>&amp;更新</translation>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="63"/>
        <source>Execute Time</source>
        <translation>実行時刻</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="65"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="67"/>
        <source>User</source>
        <translation>ユーザー</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="69"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="49"/>
        <source>&amp;Command</source>
        <translation>&amp;コマンド</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="51"/>
        <source>&amp;Variables</source>
        <translation>&amp;変数</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="53"/>
        <source>&amp;Job List</source>
        <translation>&amp;ジョブリスト</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="94"/>
        <location filename="../MainWindow.cpp" line="191"/>
        <location filename="../MainWindow.cpp" line="242"/>
        <location filename="../MainWindow.cpp" line="263"/>
        <location filename="../MainWindow.cpp" line="333"/>
        <source>Job Scheduler</source>
        <translation>スケジュール管理</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="118"/>
        <source>&amp;File</source>
        <translation>&amp;ファイル</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="119"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="122"/>
        <source>&amp;New Item</source>
        <translation>&amp;新しい項目</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="123"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="126"/>
        <source>&amp;Reload</source>
        <translation>&amp;Reload</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="127"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="129"/>
        <source>&amp;Save</source>
        <translation>&amp;Save</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="130"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="133"/>
        <source>Start as &amp;Root</source>
        <translation>&amp;Root で開始</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="135"/>
        <source>Start as &amp;Regular user</source>
        <translation>Start as &amp;Regular user</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="140"/>
        <source>E&amp;xit</source>
        <translation>E&amp;xit</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="148"/>
        <source>&amp;Edit</source>
        <translation>&amp;編集</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="149"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="151"/>
        <source>Cu&amp;t</source>
        <translation>Cu&amp;t</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="152"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="154"/>
        <source>&amp;Copy</source>
        <translation>&amp;コピー</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="155"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="157"/>
        <source>&amp;Paste</source>
        <translation>&amp;Paste</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="158"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="161"/>
        <source>&amp;Delete</source>
        <translation>&amp;削除</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>Del</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="173"/>
        <location filename="../MainWindow.cpp" line="176"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="175"/>
        <source>&amp;About</source>
        <translation>&amp;About</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="243"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation>前回の変更は保存されていません。
リロードしてもOKですか？</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="334"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation>直前の変更は保存されていません。
終了してもOKですか？</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="346"/>
        <source>About Job Scheduler</source>
        <translation>スケジュール管理について</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation>&lt;b&gt;スケジュール管理&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="347"/>
        <source>Version: %1</source>
        <translation>バージョン: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="348"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation>スケジュール管理ソフトのクレジット：qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="349"/>
        <source>Original project page: %1</source>
        <translation>プロジェクト元のサイト: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="350"/>
        <source>MX project page: %1</source>
        <translation>MX プロジェクトのサイト: %1</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation>新規スケジュールを保存</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation>ユーザー:</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="40"/>
        <source>User:</source>
        <translation>ユーザー:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="48"/>
        <source>Time:</source>
        <translation>時刻:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="51"/>
        <source>Time String E&amp;ditor</source>
        <translation>時刻文字列 E&amp;ditor</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="55"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="61"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="64"/>
        <source>Job Schedule:</source>
        <translation>スケジュール管理:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="126"/>
        <source>Time Format Error</source>
        <translation>時刻形式エラー</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="143"/>
        <source>Today</source>
        <translation>今日</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="145"/>
        <source>Tomorrow</source>
        <translation>明日</translation>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="75"/>
        <source>time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="80"/>
        <source>Minute</source>
        <translation>分</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="92"/>
        <source>Hour</source>
        <translation>時</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="98"/>
        <source>AM </source>
        <translation>午前</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="104"/>
        <source>PM </source>
        <translation>午後</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="111"/>
        <source>Day</source>
        <translation>日</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="126"/>
        <source>Month</source>
        <translation>月</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="140"/>
        <source>Week</source>
        <translation>週</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="152"/>
        <source>Simple</source>
        <translation>簡易</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="166"/>
        <source>Enable Literal</source>
        <translation>リテラルの有効化</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="168"/>
        <source>&amp;Reset</source>
        <translation>&amp;リセット</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="46"/>
        <source>Variables</source>
        <translation>変数</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="51"/>
        <source>Mail:</source>
        <translation>Mail:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Don&apos;t send</source>
        <translation>送信しない</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Send</source>
        <translation>送る</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>To</source>
        <translation>へ</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="66"/>
        <source>&amp;New</source>
        <translation>&amp;New</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="69"/>
        <source>&amp;Delete</source>
        <translation>&amp;削除</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="77"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="82"/>
        <source>Value:</source>
        <translation>値:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="85"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
</context>
</TS>

==> job-scheduler_0.22.10.01.tar.xz: 64/translations/job-scheduler_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CronModel</name>
    <message>
        <location filename="../CronModel.cpp" line="114"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="116"/>
        <source>User</source>
        <translation>ユーザー</translation>
    </message>
    <message>
        <location filename="../CronModel.cpp" line="118"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
</context>
<context>
    <name>ExecuteList</name>
    <message>
        <location filename="../ExecuteList.cpp" line="36"/>
        <source>Max Item</source>
        <translation>アイテムの最大</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="38"/>
        <source>Max Date</source>
        <translation>最大の日付</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="40"/>
        <source>Select</source>
        <translation>選択</translation>
    </message>
    <message>
        <location filename="../ExecuteList.cpp" line="44"/>
        <source>&amp;Update</source>
        <translation>&amp;更新</translation>
    </message>
</context>
<context>
    <name>ExecuteModel</name>
    <message>
        <location filename="../ExecuteModel.cpp" line="63"/>
        <source>Execute Time</source>
        <translation>実行時刻</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="65"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="67"/>
        <source>User</source>
        <translation>ユーザー</translation>
    </message>
    <message>
        <location filename="../ExecuteModel.cpp" line="69"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.cpp" line="50"/>
        <source>&amp;Command</source>
        <translation>&amp;コマンド</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="52"/>
        <source>&amp;Variables</source>
        <translation>&amp;変数</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="54"/>
        <source>&amp;Job List</source>
        <translation>&amp;ジョブリスト</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="95"/>
        <location filename="../MainWindow.cpp" line="188"/>
        <location filename="../MainWindow.cpp" line="233"/>
        <location filename="../MainWindow.cpp" line="254"/>
        <location filename="../MainWindow.cpp" line="324"/>
        <source>Job Scheduler</source>
        <translation>スケジュール管理</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="119"/>
        <source>&amp;File</source>
        <translation>&amp;ファイル</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="120"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="123"/>
        <source>&amp;New Item</source>
        <translation>&amp;新しい項目</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="124"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="127"/>
        <source>&amp;Reload</source>
        <translation>&amp;Reload</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="128"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="130"/>
        <source>&amp;Save</source>
        <translation>&amp;Save</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="131"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="134"/>
        <source>Start as &amp;Root</source>
        <translation>&amp;Root で開始</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="136"/>
        <source>Start as &amp;Regular user</source>
        <translation>Start as &amp;Regular user</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="137"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="141"/>
        <source>E&amp;xit</source>
        <translation>E&amp;xit</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="142"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="149"/>
        <source>&amp;Edit</source>
        <translation>&amp;編集</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="150"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="152"/>
        <source>Cu&amp;t</source>
        <translation>Cu&amp;t</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="153"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="155"/>
        <source>&amp;Copy</source>
        <translation>&amp;コピー</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="156"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="158"/>
        <source>&amp;Paste</source>
        <translation>&amp;Paste</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="159"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="162"/>
        <source>&amp;Delete</source>
        <translation>&amp;削除</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="163"/>
        <source>Del</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="174"/>
        <location filename="../MainWindow.cpp" line="177"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="176"/>
        <source>&amp;About</source>
        <translation>&amp;About</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="234"/>
        <source>Not saved since last change.
Are you OK to reload?</source>
        <translation>前回の変更は保存されていません。
リロードしてもOKですか？</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="325"/>
        <source>Not saved since last change.
Are you OK to exit?</source>
        <translation>直前の変更は保存されていません。
終了してもOKですか？</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>About Job Scheduler</source>
        <translation>スケジュール管理について</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>&lt;b&gt;Job Scheduler&lt;/b&gt;</source>
        <translation>&lt;b&gt;スケジュール管理&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="338"/>
        <source>Version: %1</source>
        <translation>バージョン: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="339"/>
        <source>Job Scheduler is based upon qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</source>
        <translation>スケジュール管理ソフトのクレジット：qroneko 0.5.4, released in 2005 by korewaisai (&lt;a href=&quot;mailto:korewaisai@yahoo.co.jp&quot;&gt;korewaisai@yahoo.co.jp&lt;/a&gt;)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="340"/>
        <source>Original project page: %1</source>
        <translation>プロジェクト元のサイト: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="341"/>
        <source>MX project page: %1</source>
        <translation>MX プロジェクトのサイト: %1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="343"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../SaveDialog.cpp" line="19"/>
        <source>Save New Schedule</source>
        <translation>新規スケジュールを保存</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="32"/>
        <source>User:</source>
        <translation>ユーザー:</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="40"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../SaveDialog.cpp" line="41"/>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
</context>
<context>
    <name>TCommandEdit</name>
    <message>
        <location filename="../TCommandEdit.cpp" line="40"/>
        <source>User:</source>
        <translation>ユーザー:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="48"/>
        <source>Time:</source>
        <translation>時刻:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="51"/>
        <source>Time String E&amp;ditor</source>
        <translation>時刻文字列 E&amp;ditor</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="55"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="61"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="64"/>
        <source>Job Schedule:</source>
        <translation>スケジュール管理:</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="126"/>
        <source>Time Format Error</source>
        <translation>時刻形式エラー</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="143"/>
        <source>Today</source>
        <translation>今日</translation>
    </message>
    <message>
        <location filename="../TCommandEdit.cpp" line="145"/>
        <source>Tomorrow</source>
        <translation>明日</translation>
    </message>
</context>
<context>
    <name>TimeDialog</name>
    <message>
        <location filename="../TimeDialog.cpp" line="75"/>
        <source>time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="80"/>
        <source>Minute</source>
        <translation>分</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="92"/>
        <source>Hour</source>
        <translation>時</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="98"/>
        <source>AM </source>
        <translation>午前</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="104"/>
        <source>PM </source>
        <translation>午後</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="111"/>
        <source>Day</source>
        <translation>日</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="126"/>
        <source>Month</source>
        <translation>月</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="140"/>
        <source>Week</source>
        <translation>週</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="152"/>
        <source>Simple</source>
        <translation>簡易</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="166"/>
        <source>Enable Literal</source>
        <translation>リテラルの有効化</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="168"/>
        <source>&amp;Reset</source>
        <translation>&amp;リセット</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="169"/>
        <source>&amp;Cancel</source>
        <translation>&amp;キャンセル</translation>
    </message>
    <message>
        <location filename="../TimeDialog.cpp" line="170"/>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>VariableEdit</name>
    <message>
        <location filename="../VariableEdit.cpp" line="46"/>
        <source>Variables</source>
        <translation>変数</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="51"/>
        <source>Mail:</source>
        <translation>Mail:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="52"/>
        <source>Don&apos;t send</source>
        <translation>送信しない</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="53"/>
        <source>Send</source>
        <translation>送る</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="54"/>
        <source>To</source>
        <translation>へ</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="66"/>
        <source>&amp;New</source>
        <translation>&amp;New</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="69"/>
        <source>&amp;Delete</source>
        <translation>&amp;削除</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="77"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="82"/>
        <source>Value:</source>
        <translation>値:</translation>
    </message>
    <message>
        <location filename="../VariableEdit.cpp" line="85"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
</context>
<context>
    <name>VariableModel</name>
    <message>
        <location filename="../VariableModel.cpp" line="37"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="../VariableModel.cpp" line="39"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
</context>
</TS>
